
# Changes

Version 1.0.8 (2020-9-8)

We closed a total of 11 issues (enhancements and bug fixes) through 5 pull requests, since our last release on 2019-7-18.

## Issues Closed
  - version bump (#29)
  - fix check_constant returns (#28)
  - logistic  GLM? (#27)
  - addressing pysal/pysal#1145 (#26)
  - update changeling (#25)
  - version bump (#24)

## Pull Requests
  - version bump (#29)
  - fix check_constant returns (#28)
  - addressing pysal/pysal#1145 (#26)
  - update changeling (#25)
  - version bump (#24)

The following individuals contributed to this release:

  - Taylor Oshan
  - Ziqi Li
  - Wei Kang
  - James Gaboardi
